/*
 * (C) Copyright 2005 Tundra Semiconductor Corp.
 * http://www.tundra.com/Support/SupportForm.cfm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */


/*-----------------------------------------------------------------------------
* FILENAME: ts_clk.h
*
* DESCRIPTION: Header file contains the TSI108 CLK register definitions
*				and bitmasks
* HISTORY:
*
*    Rev. Date       Author  Description
*    ---- ---------  ------  ------------------------------------------
*         July 7,05	 timf	 updated registers to reflect TSI108A changes/additions
*         Feb 23,05  timf    combined indexed registers (removed flat list)
*							 made header sw dev friendly
*         Feb 10,05  klai    generated swiffered regmap
*
*----------------------------------------------------------------------------*/

/* The Tundra Tsi109 : Host Bridge for PowerPC is a superset of
 * the Tundra Tsi108: Host Bridge for PowerPC.  The Tsi109 is
 * software backwards compatible with the Tsi108 and any new
 * definitions specific to the Tsi109 are clearly indicated.   */



#ifndef _TS_CLK_H_
#define _TS_CLK_H_

/* ************************************************ */
/* CLK : Register address offset definitions    */
/* ************************************************ */
#define CG_INT_STATUS                                            (0x00000200)
#define CG_INT_SET                                               (0x00000204)
#define CG_INT_CTRL                                              (0x00000208)
#define CG_CLK_CTRL                                              (0x0000020c)
#define CG_PLL0_CTRL0                                            (0x00000210)
#define CG_PLL0_CTRL1                                            (0x00000214)
#define CG_PLL1_CTRL0                                            (0x00000220)
#define CG_PLL1_CTRL1                                            (0x00000224)
#define CG_IO_CTRL                                               (0x00000230)
#define CG_PWRUP_STATUS                                          (0x00000234)

/* ************************************************ */
/* CLK : Register Bit Masks and Reset Values    */
/*           definitions for every register         */
/* ************************************************ */

/* CG_INT_STATUS : Register Bits Masks Definitions */
#define CG_INT_STATUS_R_SLIP                                     (0x00000003)
#define CG_INT_STATUS_R_SLIP_CG0                                 (0x00000001)
#define CG_INT_STATUS_R_SLIP_CG1                                 (0x00000002)
#define CG_INT_STATUS_FB_SLIP                                    (0x00000300)
#define CG_INT_STATUS_FB_SLIP_CG0                                (0x00000100)
#define CG_INT_STATUS_FB_SLIP_CG1                                (0x00000200)
#define CG_INT_STATUS_LOL                                        (0x000f0000)
#define CG_INT_STATUS_LOL_CG0                                    (0x00010000)
#define CG_INT_STATUS_LOL_CG1                                    (0x00020000)
#define CG_INT_STATUS_LOL_PCI                                    (0x00040000)
#define CG_INT_STATUS_RWMASK                                     (0x000f0303)
#define CG_INT_STATUS_RESERVED                                   (0xfff0fcfc)

/* CG_INT_SET : Register Bits Masks Definitions */
#define CG_INT_SET_R_SLIP_SET                                    (0x00000003)
#define CG_INT_SET_R_SLIP_SET_CG0                                (0x00000001)
#define CG_INT_SET_R_SLIP_SET_CG1                                (0x00000002)
#define CG_INT_SET_FB_SLIP_SET                                   (0x00000300)
#define CG_INT_SET_FB_SLIP_SET_CG0                               (0x00000100)
#define CG_INT_SET_FB_SLIP_SET_CG1                               (0x00000200)
#define CG_INT_SET_LOL_SET                                       (0x000f0000)
#define CG_INT_SET_LOL_SET_CG0                                   (0x00010000)
#define CG_INT_SET_LOL_SET_CG1                                   (0x00020000)
#define CG_INT_SET_LOL_SET_PCI                                   (0x00040000)
#define CG_INT_SET_RWMASK                                        (0x000f0303)
#define CG_INT_SET_RESERVED                                      (0xfff0fcfc)

/* CG_INT_CTRL : Register Bits Masks Definitions */
#define CG_INT_CTRL_R_SLIP_EN                                    (0x00000003)
#define CG_INT_CTRL_R_SLIP_EN_CG0                                (0x00000001)
#define CG_INT_CTRL_R_SLIP_EN_CG1                                (0x00000002)
#define CG_INT_CTRL_FB_SLIP_EN                                   (0x00000300)
#define CG_INT_CTRL_FB_SLIP_EN_CG0                               (0x00000100)
#define CG_INT_CTRL_FB_SLIP_EN_CG1                               (0x00000200)
#define CG_INT_CTRL_LOL_EN                                       (0x000f0000)
#define CG_INT_CTRL_LOL_EN_CG0                                   (0x00010000)
#define CG_INT_CTRL_LOL_EN_CG1                                   (0x00020000)
#define CG_INT_CTRL_LOL_EN_PCI                                   (0x00040000)
#define CG_INT_CTRL_RWMASK                                       (0x000f0303)
#define CG_INT_CTRL_RESERVED                                     (0xfff0fcfc)


/* CG_CLK_CTRL : Register Bits Masks Definitions */
#define CG_CLK_CTRL_PB_OCN                                       (0x00000100)
#define CG_CLK_CTRL_SD_OCN                                       (0x00000200)
#define CG_CLK_CTRL_E_OCN                                        (0x00000400)
#define CG_CLK_CTRL_HLP_OCN                                      (0x00000800)
#define CG_CLK_CTRL_DMA_OCN                                      (0x00001000)
#define CG_CLK_CTRL_PCI_OCN                                      (0x00002000)
#define CG_CLK_CTRL_DMAPE_OCN                                    (0x00004000)
#define CG_CLK_CTRL_PCI1_OCN                                     (0x00008000)
#define CG_CLK_CTRL_RWMASK                                       (0x0017ff40)
#define CG_CLK_CTRL_RESERVED                                     (0xffe800bf)


#define MAX_CG_PLL	2

/* CG_PLLX_CTRL0 : Register Bits Masks Definitions */
#define CG_PLLX_CTRL0_CLKS                                       (0x000001ff)
#define CG_PLLX_CTRL0_CLKV                                       (0x01ff0000)
#define CG_PLLX_CTRL0_PWRDWN                                     (0x40000000)
#define CG_PLLX_CTRL0_SSEN                                       (0x80000000)
#define CG_PLLX_CTRL0_RWMASK                                     (0xc1ff01ff)
#define CG_PLLX_CTRL0_RESERVED                                   (0x3e00fe00)

/* CG_PLLX_CTRL1 : Register Bits Masks Definitions */
#define CG_PLLX_CTRL1_BWADJ                                      (0x000001ff)
#define CG_PLL0_CTRL1_RWMASK                                     (0x000001ff)
#define CG_PLLX_CTRL1_RESERVED                                   (0xfffffe00)

/* CG_IO_CTRL : Register Bits Masks Definitions */
#define CG_IO_CTRL_PB_EN                                         (0x00000007)
#define CG_IO_CTRL_PB_VAL                                        (0x00000070)
#define CG_IO_CTRL_PCI_EN                                        (0x00000f00)
#define CG_IO_CTRL_PCI_VAL                                       (0x000f0000)
#define CG_IO_CTRL_PCI1_EN                                       (0x0000f000)
#define CG_IO_CTRL_PCI1_VAL                                      (0x00f00000)
#define CG_IO_CTRL_RWMASK                                        (0x07ffff77)
#define CG_IO_CTRL_RESERVED                                      (0xf8000088)

/* CG_PWRUP_STATUS : Register Bits Masks Definitions */
#define CG_PWRUP_STATUS_PCI_ARB                                  (0x00000001)
#define CG_PWRUP_STATUS_PCI_BYP                                  (0x00000002)
#define CG_PWRUP_STATUS_PCI_SWRST                                (0x00000004)
#define CG_PWRUP_STATUS_SPARE3                                   (0x00000008)
#define CG_PWRUP_STATUS_SPARE4                                   (0x00000010)
#define CG_PWRUP_STATUS_HLP_WIDTH                                (0x00000018)
#define CG_PWRUP_STATUS_PB_BYP                                   (0x00000020)
#define CG_PWRUP_STATUS_PB_BMODE                                 (0x00000040)
#define CG_PWRUP_STATUS_PB_SWRST                                 (0x00000080)
#define CG_PWRUP_STATUS_PB_PUEN                                  (0x00000100)
#define CG_PWRUP_STATUS_HLP_LATCH                                (0x00000200)
#define CG_PWRUP_STATUS_SD_BYP                                   (0x00000400)
#define CG_PWRUP_STATUS_HLP_BSWAP                                (0x00000800)
#define CG_PWRUP_STATUS_PB_CPU                                   (0x00001000)
#define CG_PWRUP_STATUS_PCI1_SWRST                               (0x00002000)
#define CG_PWRUP_STATUS_PB_BVS                                   (0x00004000)
#define CG_PWRUP_STATUS_PCI1_BYP                                 (0x00008000)
#define CG_PWRUP_STATUS_CG_PB_SELECT                             (0x00070000)
#define CG_PWRUP_STATUS_CG_SD_SELECT                             (0x00700000)
#define CG_PWRUP_STATUS_PCI1_HOST                                (0x40000000)
#define CG_PWRUP_STATUS_PCI_HOST                                 (0x80000000)
#define CG_PWRUP_STATUS_RESERVED                                 (0x3f880000)

/* CG_PVT_CTRL : Register Bits Masks Definitions */
#define CG_PVT_CTRL                                              (0x00000240)
#define CG_PVT_CTRL_CSR_IN_NCH                                   (0x0000000f)
#define CG_PVT_CTRL_CSR_IN_NCH_FINE                              (0x00000100)
#define CG_PVT_CTRL_CSR_IN_PCH                                   (0x000000f0)
#define CG_PVT_CTRL_CSR_IN_PCH_FINE                              (0x00000200)
#define CG_PVT_CTRL_RWMASK                                       (0x000003ff)
#define CG_PVT_CTRL_RESERVED                                     (0xfffffc00)



#endif /* _TS_CLK_H_  */
