/*
 * (C) Copyright 2005 Tundra Semiconductor Corp.
 * http://www.tundra.com/Support/SupportForm.cfm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*-----------------------------------------------------------------------------
* FILENAME: ts_dma.h
*
* DESCRIPTION: Header file contains the TSI108 DMA port register definitions
*				and bitmasks
* HISTORY:
*
*    Rev. Date       Author  Description
*    ---- ---------  ------  ------------------------------------------
*         July 7,05	 timf	 updated registers to reflect TSI108A changes/additions
*         Feb 24,05  timf    combined indexed registers (removed flat list)
*							 made header sw dev friendly
*         Feb 10,05  klai    generated swiffered regmap
*
*----------------------------------------------------------------------------*/

/* The Tundra Tsi109 : Host Bridge for PowerPC is a superset of
 * the Tundra Tsi108: Host Bridge for PowerPC.  The Tsi109 is
 * software backwards compatible with the Tsi108 and any new
 * definitions specific to the Tsi109 are clearly indicated.   */

#ifndef _TS_DMA_H_
#define _TS_DMA_H_

/* ************************************************ */
/* DMA : Register address offset definitions    */
/* ************************************************ */

#define MAX_DMA_PORTS                4
#define DMA_CHX_SRC_ADDR_M          (0x000)
#define DMA_CHX_SRC_ADDR_L          (0x004)
#define DMA_CHX_DST_ADDR_M          (0x008)
#define DMA_CHX_DST_ADDR_L          (0x00c)
#define DMA_CHX_TCR1                (0x010)
#define DMA_CHX_TCR2                (0x014)
#define DMA_CHX_ND_ADDR_M           (0x018)
#define DMA_CHX_ND_ADDR_L           (0x01c)
#define DMA_CHX_ND_TCR              (0x020)
#define DMA_CHX_GCSR                (0x024)
#define DMA_CHX_CRC_ADDR_M          (0x028)
#define DMA_CHX_CRC_ADDR_L          (0x02c)
#define DMA_CHX_CRC                 (0x030)

/* XOR src address registers x= dma chan num, y=SRC num*/
/* note first src register index xor is 1 not 0 */
#define MAX_SRC							15
#define DMA_CHX_SRCX_ADDR_M(y)        (0x040 + ((y-1)*8))
#define DMA_CHX_SRCX_ADDR_L(y)        (0x044 + ((y-1)*8))

#define DMA_DMA_OCN_SOFT_RST                                         (0x00000400)

/* ************************************************ */
/* DMA : Register Bit Masks and Reset Values    */
/*           definitions for every register         */
/* ************************************************ */

/* DMA_CHX_SRC_ADDR_M : Register Bits Masks Definitions */
#define DMA_CHX_SRC_ADDR_M_SRC_ADDR_MB                               (0xffffffff)

/* DMA_CHX_SRC_ADDR_L : Register Bits Masks Definitions */
#define DMA_CHX_SRC_ADDR_L_SRC_ADDR_LB                               (0xffffffff)

/* DMA_CHX_DST_ADDR_M : Register Bits Masks Definitions */
#define DMA_CHX_DST_ADDR_M_DST_ADDR_MB                               (0xffffffff)

/* DMA_CHX_DST_ADDR_L : Register Bits Masks Definitions */
#define DMA_CHX_DST_ADDR_L_DST_ADDR_LB                               (0xffffffff)

/* DMA_CHX_TCR1 : Register Bits Masks Definitions */
#define DMA_CHX_TCR1_DATA_BLOCKS                                     (0x0000000f)
#define DMA_CHX_TCR1_DIRECT_FILL                                     (0x00000020)
#define DMA_CHX_TCR1_DST_PORT                                        (0x00003f00)
#define DMA_CHX_TCR1_DIS_DMA_WR                                      (0x00008000)
#define DMA_CHX_TCR1_SRC_PORT                                        (0x003f0000)
#define DMA_CHX_TCR1_READ_CRC_SEED                                   (0x00400000)
#define DMA_CHX_TCR1_CRC_WR_EN                                       (0x00800000)
#define DMA_CHX_TCR1_CRC_PORT                                        (0x3f000000)
#define DMA_CHX_TCR1_CRC_EN                                          (0x40000000)
#define DMA_CHX_TCR1_XOR_WR_EN                                       (0x80000000)
#define DMA_CHX_TCR1_RESERVED                                        (0x000040d0)

/* DMA_CHX_TCR2 : Register Bits Masks Definitions */
#define DMA_CHX_TCR2_BC                                              (0x00ffffff)
#define DMA_CHX_TCR2_SWAP                                            (0x03000000)
#define DMA_CHX_TCR2_BURST_SIZE                                      (0x0c000000)
#define DMA_CHX_TCR2_CRC_SWAP                                        (0x30000000)
#define DMA_CHX_TCR2_CRC_ORIENT                                      (0x80000000)
#define DMA_CHX_TCR2_RESERVED                                        (0x40000000)

/* DMA_CHX_ND_ADDR_M : Register Bits Masks Definitions */
#define DMA_CHX_ND_ADDR_M_ND_ADDR_MB                                 (0xffffffff)

/* DMA_CHX_ND_ADDR_L : Register Bits Masks Definitions */
#define DMA_CHX_ND_ADDR_L_LAST                                       (0x00000001)
#define DMA_CHX_ND_ADDR_L_ND_ADDR_LB                                 (0xffffffc0)
#define DMA_CHX_ND_ADDR_L_RESERVED                                   (0x0000003e)

/* DMA_CHX_ND_TCR : Reset Value */
#define DMA_CHX_ND_TCR_RESET_VALUE                                   (0x00030000)

/* DMA_CHX_ND_TCR : Register Bits Masks Definitions */
#define DMA_CHX_ND_TCR_ND_DATA_BLOCKS                                (0x000f0000)
#define DMA_CHX_ND_TCR_ND_PORT                                       (0x3f000000)
#define DMA_CHX_ND_TCR_ND_SWAP                                       (0xc0000000)
#define DMA_CHX_ND_TCR_RESERVED                                      (0x00f0ffff)

/* DMA_CHX_GCSR : Register Bits Masks Definitions */
#define DMA_CHX_GCSR_DONE_EN                                         (0x00000001)
#define DMA_CHX_GCSR_HALT_EN                                         (0x00000002)
#define DMA_CHX_GCSR_STOP_EN                                         (0x00000004)
#define DMA_CHX_GCSR_EX_PKT_EN                                       (0x00000008)
#define DMA_CHX_GCSR_ERR_EN                                          (0x00000010)
#define DMA_CHX_GCSR_PERR_EN                                         (0x00000020)
#define DMA_CHX_GCSR_PERR                                            (0x00000040)
#define DMA_CHX_GCSR_EX_PKT_ERR                                      (0x00000080)
#define DMA_CHX_GCSR_DONE                                            (0x00000100)
#define DMA_CHX_GCSR_HALT                                            (0x00000200)
#define DMA_CHX_GCSR_STOP                                            (0x00000400)
#define DMA_CHX_GCSR_RESUME                                          (0x00000800)
#define DMA_CHX_GCSR_ERR_OUT                                         (0x00001000)
#define DMA_CHX_GCSR_ERR_IN                                          (0x00002000)
#define DMA_CHX_GCSR_DACT                                            (0x00800000)
#define DMA_CHX_GCSR_SOFT_RST                                        (0x01000000)
#define DMA_CHX_GCSR_HALT_REQ                                        (0x02000000)
#define DMA_CHX_GCSR_STOP_REQ                                        (0x04000000)
#define DMA_CHX_GCSR_OP_CMD                                          (0x30000000)
#define DMA_CHX_GCSR_CHAIN                                           (0x40000000)
#define DMA_CHX_GCSR_GO                                              (0x80000000)
#define DMA_CHX_GCSR_RWMASK                                          (0xf7003fff)
#define DMA_CHX_GCSR_RESERVED                                        (0x087fc000)

/* DMA_CHX_CRC_ADDR_M : Register Bits Masks Definitions */
#define DMA_CHX_CRC_ADDR_M_CRC_ADDR_MB                               (0xffffffff)

/* DMA_CHX_CRC_ADDR_L : Register Bits Masks Definitions */
#define DMA_CHX_CRC_ADDR_L_CRC_ADDR_LB                               (0xffffffff)

/* DMA_CHX_CRC : Register Bits Masks Definitions */
#define DMA_CHX_CRC_CRC                                              (0xffffffff)

/* DMA_CHX_SRCX_ADDR_M : Register Bits Masks Definitions */
#define DMA_CHX_SRCX_ADDR_M_SRC_ADDR_MB                              (0xffffffff)

/* DMA_CHX_SRCX_ADDR_L : Register Bits Masks Definitions */
#define DMA_CHX_SRCX_ADDR_L_SRC_ADDR_LB_R                            (0x00000007)
#define DMA_CHX_SRCX_ADDR_L_SRC_ADDR_LB                              (0xfffffff8)


/* DMA_DMA_OCN_SOFT_RST : Register Bits Masks Definitions */
#define DMA_DMA_OCN_SOFT_RST_OCN_SOFT_RST                            (0x00000001)
#define DMA_DMA_OCN_SOFT_RST_RESERVED                                (0xfffffffe)

#endif /* _TS_DMA_H_  */
