/*
 * (C) Copyright 2005 Tundra Semiconductor Corp.
 * http://www.tundra.com/Support/SupportForm.cfm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*-----------------------------------------------------------------------------
* FILENAME: ts_pb.h
*
* DESCRIPTION: Header file contains the TSI108 PB register definitions
*				and bitmasks
* HISTORY:
*
*    Rev. Date       Author  Description
*    ---- ---------  ------  ------------------------------------------
*         July 7,05	 timf	 updated registers to reflect TSI108A changes/additions
*         Feb 24,05  timf    combined indexed registers (removed flat list)
*							 made header sw dev friendly
*         Feb 10,05  klai    generated swiffered regmap
*
*----------------------------------------------------------------------------*/

/* The Tundra Tsi109 : Host Bridge for PowerPC is a superset of
 * the Tundra Tsi108: Host Bridge for PowerPC.  The Tsi109 is
 * software backwards compatible with the Tsi108 and any new
 * definitions specific to the Tsi109 are clearly indicated.   */


#ifndef _TS_PB_H_
#define _TS_PB_H_

/* ************************************************ */
/* PB : Register address offset definitions    */
/* ************************************************ */
#define PB_ID                                                        (0x00000000)
#define PB_RSR                                                       (0x00000004)
#define PB_BUS_MS_SELECT                                             (0x00000008)
#define PB_ISR                                                       (0x0000000c)
#define PB_IER                                                       (0x00000010)
#define PB_INT_SET                                                   (0x00000014)
#define PB_ARB_CTRL                                                  (0x00000018)
#define PB_SCRATCH_PAD                                               (0x00000020)
#define PB_PVT_CTRL1                                                 (0x00000030)
#define PB_PVT_CTRL2                                                 (0x00000034)
#define PB_PVT_S                                                     (0x00000038)
#define PB_SCR                                                       (0x00000400)
#define PB_ERRCS                                                     (0x00000404)
#define PB_AERR                                                      (0x00000408)
#define PB_REG_BAR                                                   (0x00000410)
#define PB_OCN_BAR1                                                  (0x00000414)
#define PB_OCN_BAR2                                                  (0x00000418)
#define PB_SDRAM_BAR1                                                (0x0000041c)
#define PB_SDRAM_BAR2                                                (0x00000420)
#define PB_OCN_SYNC_DATA                                             (0x00000424)
#define PB_OCN_SYNC_GEN                                              (0x00000428)

/* valid addrs : ADDR0:31 */
#define MAX_PB_BAR_ADDR												 32
/* available Bars: BAR1, BAR2*/
#define MAX_PB_BAR  												 2
#define PB_BARX_LOWER_LUT_ADDRY(x,y)                                 (0x00000800 + ((x-1)*0x100) + (y*8))
#define PB_BARX_UPPER_LUT_ADDRY(x,y)                                 (0x00000804 + ((x-1)*0x100) + (y*8))


#define PB_MCR                                                       (0x00000c00)
#define PB_MCMD                                                      (0x00000c04)

/* ************************************************ */
/* PB : Register Bit Masks and Reset Values    */
/*           definitions for every register         */
/* ************************************************ */

/* PB_ID : Reset Value */
#define PB_ID_RESET_VALUE                                            (0xa1080000)

/* PB_ID : Register Bits Masks Definitions */
#define PB_ID_TUNDRA_VER_ID                                          (0x0000ffff)
#define PB_ID_TUNDRA_DEV_ID                                          (0xffff0000)

/* PB_RSR : Register Bits Masks Definitions */
#define PB_RSR_PB_BMODEn                                             (0x00000001)
#define PB_RSR_PB_BYPASS_EN                                          (0x00000002)
#define PB_RSR_PB_PUEN                                               (0x00000004)
#define PB_RSR_PB_CPU                                                (0x00000008)
#define PB_RSR_PB_SWRST                                              (0x00000020)
#define PB_RSR_PB_BVS                                                (0x00000080)
#define PB_RSR_ADDR_WIDTH                                            (0x00000100)
#define PB_RSR_RWMASK                                                (0x000001a0)
#define PB_RSR_RESERVED                                              (0xfffffe50)


/* PB_BUS_MS_SELECT : Register Bits Masks Definitions */
#define PB_BUS_MS_SELECT_MS                                          (0x00000001)
#define PB_BUS_MS_SELECT_WAMI                                        (0x00000100)
#define PB_BUS_MS_SELECT_RESERVED                                    (0xfffffefe)

/* PB_ISR : Register Bits Masks Definitions */
#define PB_ISR_PBS_DP_ERR                                            (0x00000001)
#define PB_ISR_PBS_AP_ERR                                            (0x00000002)
#define PB_ISR_PBS_ATT_ERR                                           (0x00000004)
#define PB_ISR_PBS_WRPROTECT                                         (0x00000008)
#define PB_ISR_PBS_UNALIGN                                           (0x00000010)
#define PB_ISR_PBS_NORESP                                            (0x00000020)
#define PB_ISR_PBS_RD_ERR                                            (0x00000100)
#define PB_ISR_PBS_REQ_ERR                                           (0x00000200)
#define PB_ISR_PBS_UNXPCTED                                          (0x00000400)
#define PB_ISR_PBS_REG_TO                                            (0x00000800)
#define PB_ISR_PBS_SDRAM_TO                                          (0x00001000)
#define PB_ISR_PBS_OCN_TEA                                           (0x00002000)
#define PB_ISR_PBS_OCN_RTO                                           (0x00004000)
#define PB_ISR_SDC_INC_ADDR                                          (0x00008000)
#define PB_ISR_PBM_NORESP                                            (0x00010000)
#define PB_ISR_PBM_DEST_ERR                                          (0x00020000)
#define PB_ISR_PB_WAKE0                                              (0x00040000)
#define PB_ISR_PB_WAKE1                                              (0x00080000)
#define PB_ISR_PBM_UNXPCTED                                          (0x01000000)
#define PB_ISR_PBM_BADCMD                                            (0x02000000)
#define PB_ISR_PBM_OCN_TEA                                           (0x04000000)
#define PB_ISR_RESERVED                                              (0xf8f000c0)

/* PB_IER : Register Bits Masks Definitions */
#define PB_IER_PBS_DP_ERR_EN                                         (0x00000001)
#define PB_IER_PBS_AP_ERR_EN                                         (0x00000002)
#define PB_IER_PBS_ATT_ERR_EN                                        (0x00000004)
#define PB_IER_PBS_WRPROTECT_EN                                      (0x00000008)
#define PB_IER_PBS_UNALIGN_EN                                        (0x00000010)
#define PB_IER_PBS_NORESP_EN                                         (0x00000020)
#define PB_IER_PBS_RD_ERR_EN                                         (0x00000100)
#define PB_IER_PBS_REQ_ERR_EN                                        (0x00000200)
#define PB_IER_PBS_UNXPCTED_EN                                       (0x00000400)
#define PB_IER_PBS_REG_TO_EN                                         (0x00000800)
#define PB_IER_PBS_SDRAM_TO_EN                                       (0x00001000)
#define PB_IER_PBS_OCN_TEA_EN                                        (0x00002000)
#define PB_IER_PBS_OCN_RTO_EN                                        (0x00004000)
#define PB_IER_SDC_INC_ADDR_EN                                       (0x00008000)
#define PB_IER_PBM_NORESP_EN                                         (0x00010000)
#define PB_IER_PBM_DEST_ERR_EN                                       (0x00020000)
#define PB_IER_PB_WAKE0_EN                                           (0x00040000)
#define PB_IER_PB_WAKE1_EN                                           (0x00080000)
#define PB_IER_PBM_UNXPCTED_EN                                       (0x01000000)
#define PB_IER_PBM_BADCMD_EN                                         (0x02000000)
#define PB_IER_PBM_OCN_TEA_EN                                        (0x04000000)
#define PB_IER_RESERVED                                              (0xf8f000c0)

/* PB_INT_SET : Register Bits Masks Definitions */
#define PB_INT_SET_PBS_DP_ERR_SET                                    (0x00000001)
#define PB_INT_SET_PBS_AP_ERR_SET                                    (0x00000002)
#define PB_INT_SET_PBS_ATT_ERR_SET                                   (0x00000004)
#define PB_INT_SET_PBS_WRPROTECT_SET                                 (0x00000008)
#define PB_INT_SET_PBS_UNALIGN_SET                                   (0x00000010)
#define PB_INT_SET_PBS_NORESP_SET                                    (0x00000020)
#define PB_INT_SET_PBS_RD_ERR_SET                                    (0x00000100)
#define PB_INT_SET_PBS_REQ_ERR_SET                                   (0x00000200)
#define PB_INT_SET_PBS_UNXPCTED_SET                                  (0x00000400)
#define PB_INT_SET_PBS_REG_TO_SET                                    (0x00000800)
#define PB_INT_SET_PBS_SDRAM_TO_SET                                  (0x00001000)
#define PB_INT_SET_PBS_OCN_TEA_SET                                   (0x00002000)
#define PB_INT_SET_PBS_OCN_RTO_SET                                   (0x00004000)
#define PB_INT_SET_SDC_INC_ADDR_SET                                  (0x00008000)
#define PB_INT_SET_PBM_NORESP_SET                                    (0x00010000)
#define PB_INT_SET_PBM_DEST_ERR_SET                                  (0x00020000)
#define PB_INT_SET_PB_WAKE0_SET                                      (0x00040000)
#define PB_INT_SET_PB_WAKE1_SET                                      (0x00080000)
#define PB_INT_SET_PBM_UNXPCTED_SET                                  (0x01000000)
#define PB_INT_SET_PBM_BADCMD_SET                                    (0x02000000)
#define PB_INT_SET_PBM_OCN_TEA_SET                                   (0x04000000)
#define PB_INT_SET_RESERVED                                          (0xf8f000c0)

/* PB_ARB_CTRL : Register Bits Masks Definitions */
#define PB_ARB_CTRL_PARK                                             (0x00000001)
#define PB_ARB_CTRL_BM_PARK                                          (0x00000006)
#define PB_ARB_CTRL_ARB_PIPELINE_DEP                                 (0x000000f0)
#define PB_ARB_CTRL_M0_EN                                            (0x00000100)
#define PB_ARB_CTRL_M1_EN                                            (0x00000200)
#define PB_ARB_CTRL_PBM_EN                                           (0x00001000)
#define PB_ARB_CTRL_RESERVED                                         (0xffffec08)

/* PB_PWR_CTRL : Register Bits Masks Definitions */
#define PB_PWR_CTRL_MODE                                             (0x00000003)
#define PB_PWR_CTRL_DOZE_DELAY                                       (0x0000ff00)
#define PB_PWR_CTRL_WAKE_DELAY                                       (0x007f0000)
#define PB_PWR_CTRL_MIN_SLEEP_TIME                                   (0x3f000000)
#define PB_PWR_CTRL_RWMASK                                           (0x3f7fff03)
#define PB_PWR_CTRL_RESERVED                                         (0xc08000fc)

/* PB_PVT_CTRL1 : Register Bits Masks Definitions */
#define PB_PVT_CTRL1_CSR_OUT_NCH                                     (0x0000000f)
#define PB_PVT_CTRL1_CSR_OUT_PCH                                     (0x000000f0)
#define PB_PVT_CTRL1_CSR_OUT_NCH_FINE                                (0x00000100)
#define PB_PVT_CTRL1_CSR_OUT_PCH_FINE                                (0x00000200)
#define PB_PVT_CTRL1_CSR_NP_OVRD                                     (0x00000c00)
#define PB_PVT_CTRL1_CSR_FIL_OVRD                                    (0x00001000)
#define PB_PVT_CTRL1_CSR_OUT_FIL                                     (0x007f0000)
#define PB_PVT_CTRL1_SENSE_START                                     (0x00800000)
#define PB_PVT_CTRL1_RESERVED                                        (0xff00e000)

/* PB_PVT_CTRL2 : Register Bits Masks Definitions */
#define PB_PVT_CTRL2_PVT_CTRL_DSBL                                   (0x00000001)
#define PB_PVT_CTRL2_PVT_TIMER                                       (0x0000ff00)
#define PB_PVT_CTRL2_RESERVED                                        (0xffff00fe)

/* PB_PVT_S : Register Bits Masks Definitions */
#define PB_PVT_S_CSR_IN_NCH                                          (0x0000000f)
#define PB_PVT_S_CSR_IN_PCH                                          (0x000000f0)
#define PB_PVT_S_CSR_IN_NCH_FINE                                     (0x00000100)
#define PB_PVT_S_CSR_IN_PCH_FINE                                     (0x00000200)
#define PB_PVT_S_CSR_IN_FIL                                          (0x007f0000)
#define PB_PVT_S_RESERVED                                            (0xff80fc00)

/* PB_SCR : Register Bits Masks Definitions */
#define PB_SCR_AACK_DLY                                              (0x00000007)
#define PB_SCR_CLAIM_SYNC                                            (0x00000040)
#define PB_SCR_SDC_END_MODE                                          (0x00000080)
#define PB_SCR_AP_MODE                                               (0x00000200)
#define PB_SCR_AP_DSBL                                               (0x00000400)
#define PB_SCR_DP_MODE                                               (0x00000800)
#define PB_SCR_TEA_EN                                                (0x00002000)
#define PB_SCR_DTI_MODE                                              (0x00004000)
#define PB_SCR_SCPU_OPT                                              (0x00000008)
#define PB_SCR_RWMASK                                                (0x00006ecf)
#define PB_SCR_RESERVED                                              (0xffff9130)

/* PB_ERRCS : Register Bits Masks Definitions */
#define PB_ERRCS_MES                                                 (0x00000001)
#define PB_ERRCS_ES                                                  (0x00000002)
#define PB_ERRCS_TBST                                                (0x00000004)
#define PB_ERRCS_GBL                                                 (0x00000008)
#define PB_ERRCS_ADDR_EXT                                            (0x000000f0)
#define PB_ERRCS_TT                                                  (0x00001f00)
#define PB_ERRCS_TSIZ                                                (0x0000e000)
#define PB_ERRCS_PBM_CL                                              (0x000f0000)
#define PB_ERRCS_SOURCE                                              (0x00c00000)
#define PB_ERRCS_RESERVED                                            (0xff300000)

/* PB_AERR : Register Bits Masks Definitions */
#define PB_AERR_ADDR                                                 (0xffffffff)

/* PB_REG_BAR : Register Bits Masks Definitions */
#define PB_REG_BAR_EN                                                (0x00000001)
#define PB_REG_BAR_END_MODE                                          (0x0000000c)
#define PB_REG_BAR_BA_UPPER                                          (0x0000f000)
#define PB_REG_BAR_BA                                                (0xffff0000)
#define PB_REG_BAR_RESERVED                                          (0x00000ff2)

/* PB_OCN_BAR1 : Register Bits Masks Definitions */
#define PB_OCN_BAR1_EN                                               (0x00000001)
#define PB_OCN_BAR1_BOOT                                             (0x00000002)
#define PB_OCN_BAR1_SIZE                                             (0x000000f0)
#define PB_OCN_BAR1_BA_UPPER                                         (0x0000f000)
#define PB_OCN_BAR1_BA                                               (0xf0000000)
#define PB_OCN_BAR1_RESERVED                                         (0x0fff0f0c)

/* PB_OCN_BAR2 : Register Bits Masks Definitions */
#define PB_OCN_BAR2_EN                                               (0x00000001)
#define PB_OCN_BAR2_SIZE                                             (0x000000f0)
#define PB_OCN_BAR2_BA_UPPER                                         (0x0000f000)
#define PB_OCN_BAR2_BA                                               (0xf0000000)
#define PB_OCN_BAR2_RESERVED                                         (0x0fff0f0e)

/* PB_SDRAM_BAR1 : Register Bits Masks Definitions */
#define PB_SDRAM_BAR1_EN                                             (0x00000001)
#define PB_SDRAM_BAR1_WR_PRTC                                        (0x00000002)
#define PB_SDRAM_BAR1_SIZE                                           (0x000000f0)
#define PB_SDRAM_BAR1_TA_UPPER                                       (0x00000f00)
#define PB_SDRAM_BAR1_BA_UPPER                                       (0x0000f000)
#define PB_SDRAM_BAR1_ATE                                            (0x00010000)
#define PB_SDRAM_BAR1_TA                                             (0x0f000000)
#define PB_SDRAM_BAR1_BA                                             (0xf0000000)
#define PB_SDRAM_BAR1_RESERVED                                       (0x00fe000c)

/* PB_SDRAM_BAR2 : Register Bits Masks Definitions */
#define PB_SDRAM_BAR2_EN                                             (0x00000001)
#define PB_SDRAM_BAR2_WR_PRTC                                        (0x00000002)
#define PB_SDRAM_BAR2_SIZE                                           (0x000000f0)
#define PB_SDRAM_BAR2_TA_UPPER                                       (0x00000f00)
#define PB_SDRAM_BAR2_BA_UPPER                                       (0x0000f000)
#define PB_SDRAM_BAR2_ATE                                            (0x00010000)
#define PB_SDRAM_BAR2_TA                                             (0x0f000000)
#define PB_SDRAM_BAR2_BA                                             (0xf0000000)
#define PB_SDRAM_BAR2_RESERVED                                       (0x00fe000c)

/* PB_OCN_SYNC_DATA : Register Bits Masks Definitions */
#define PB_OCN_SYNC_DATA_DEST1                                       (0x0000000f)
#define PB_OCN_SYNC_DATA_DEST2                                       (0x00000f00)
#define PB_OCN_SYNC_DATA_RESERVED                                    (0xfffff0f0)

/* PB_BARX_LOWER_LUT_ADDRY : Register Bits Masks Definitions */
#define PB_BARX_LOWER_LUT_ADDRY_DST_PORT                             (0x0000000f)
#define PB_BARX_LOWER_LUT_ADDRY_ATE                                  (0x00000040)
#define PB_BARX_LOWER_LUT_ADDRY_WR_PRTC                              (0x00000080)
#define PB_BARX_LOWER_LUT_ADDRY_END_MODE                             (0x00000300)
#define PB_BARX_LOWER_LUT_ADDRY_TA                                   (0xff800000)
#define PB_BARX_LOWER_LUT_ADDRY_RESERVED                             (0x007ffc30)

/* PB_BARX_UPPER_LUT_ADDRY : Register Bits Masks Definitions */
#define PB_BARX_UPPER_LUT_ADDRY_TA                                   (0xffffffff)

/* PBM_CR : Reset Value */
#define PBM_CR_RESET_VALUE                                           (0x00000c04)

/* PBM_CR : Register Bits Masks Definitions */
#define PB_MCR_FLUSH_TT                                              (0x0000001f)
#define PB_MCR_FLUSH_TSIZ                                            (0x000000e0)
#define PB_MCR_KILL_TT                                               (0x00001f00)
#define PB_MCR_KILL_TSIZ                                             (0x0000e000)
#define PB_MCR_CLEAN_TT                                              (0x001f0000)
#define PB_MCR_CLEAN_TSIZ                                            (0x00e00000)
#define PB_MCR_FLUSH_TBST                                            (0x01000000)
#define PB_MCR_KILL_TBST                                             (0x02000000)
#define PB_MCR_CLEAN_TBST                                            (0x04000000)
#define PB_MCR_AP_MODE                                               (0x10000000)
#define PB_MCR_RWMASK                                                (0x17ffffff)
#define PB_MCR_RESERVED                                              (0xe8000000)


/* PB_MCMD : Reset Value */
#define PB_MCMD_RESET_VALUE                                          (0x0000aa45)

/* PB_MCMD : Register Bits Masks Definitions */
#define PB_MCMD_FCW_WB_CMD                                           (0x00000003)
#define PB_MCMD_FCW_WT_CMD                                           (0x0000000c)
#define PB_MCMD_PCW_WB_CMD                                           (0x00000030)
#define PB_MCMD_PCW_WT_CMD                                           (0x000000c0)
#define PB_MCMD_FCR_WB_CMD                                           (0x00000300)
#define PB_MCMD_FCR_WT_CMD                                           (0x00000c00)
#define PB_MCMD_PCR_WB_CMD                                           (0x00003000)
#define PB_MCMD_PCR_WT_CMD                                           (0x0000c000)
#define PB_MCMD_RESERVED                                             (0xffff0000)

#endif /* _TS_PB_H_  */
