/*
 * (C) Copyright 2005 Tundra Semiconductor Corp.
 * http://www.tundra.com/Support/SupportForm.cfm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*-----------------------------------------------------------------------------
* FILENAME: ts_pci.h
*
* DESCRIPTION: Header file contains the TSI108 PCI port register definitions
*				and bitmasks
* HISTORY:
*
*    Rev. Date       Author  Description
*    ---- ---------  ------  ------------------------------------------
*         July 7,05	 timf	 updated registers to reflect TSI108A changes/additions
*         Feb 24,05  timf    combined indexed registers (removed flat list)
*							 made header sw dev friendly
*         Feb 10,05  klai    generated swiffered regmap
*
*----------------------------------------------------------------------------*/

/* The Tundra Tsi109 : Host Bridge for PowerPC is a superset of
 * the Tundra Tsi108: Host Bridge for PowerPC.  The Tsi109 is
 * software backwards compatible with the Tsi108 and any new
 * definitions specific to the Tsi109 are clearly indicated.   */

#ifndef _TS_PCI_H_
#define _TS_PCI_H_

/* ************************************************ */
/* PCI : Register address offset definitions    */
/* ************************************************ */
/* PCIX general configuration space map */
#define PCI_PE_ID                                                    (0x00000000)
#define PCI_PE_CSR                                                   (0x00000004)
#define PCI_PE_CLASS                                                 (0x00000008)
#define PCI_PE_MISC0                                                 (0x0000000c)
#define PCI_P2O_BAR0                                                 (0x00000010)
#define PCI_P2O_BAR0_UPPER                                           (0x00000014)
#define PCI_P2O_BAR2                                                 (0x00000018)
#define PCI_P2O_BAR2_UPPER                                           (0x0000001c)
#define PCI_P2O_BAR3                                                 (0x00000020)
#define PCI_P2O_BAR3_UPPER                                           (0x00000024)
#define PCI_PE_SID                                                   (0x0000002c)
#define PCI_PE_ROM                                                   (0x00000030)
#define PCI_PE_CAP                                                   (0x00000034)
#define PCI_PE_MISC2                                                 (0x0000003c)
#define PCI_MISC_CSR                                                 (0x00000040)
#define PCI_SERR_DIS                                                 (0x00000044)
#define PCI_SERR_STAT                                                (0x00000048)
#define PCI_P2O_PAGE_SIZES                                           (0x0000004c)
#define PCI_P_VPD_                                                   (0x00000050)
#define PCI_P_SLOT_ID                                                (0x000000c8)
#define PCI_P_PMC                                                    (0x000000cc)
#define PCI_P_PMCS                                                   (0x000000d0)
#define PCI_P_HS_CSR                                                 (0x000000d4)
#define PCI_P_VPDC                                                   (0x000000d8)
#define PCI_P_VPDD                                                   (0x000000dc)
#define PCI_P_MSIC                                                   (0x000000e0)
#define PCI_P_MSIA                                                   (0x000000e4)
#define PCI_P_MSIA_UPPER                                             (0x000000e8)
#define PCI_P_MSID                                                   (0x000000ec)
#define PCI_PE_PCIX_C                                                (0x000000f0)
#define PCI_PE_PCIX_S                                               (0x000000f4)

/* device specific*/
#define PCI_ARB_CTRL                                                 (0x0000010c)
#define PCI_IRP_CFG_CTL                                              (0x00000180)
#define PCI_IRP_STAT                                                 (0x00000184)
#define PCI_IRP_ENABLE                                               (0x00000188)
#define PCI_IRP_INTAD                                                (0x0000018c)
#define PCI_P_VID_OVERRIDE                                           (0x0000019c)
#define PCI_P_CLASS_OVERRIDE                                         (0x000001a0)
#define PCI_PE_SID_OVERRIDE                                          (0x000001a4)
#define PCI_P_SLOT_ID_OVERRIDE                                       (0x000001a8)

/* misc device specific*/
#define PCI_PFAB_CSR                                                 (0x00000200)
#define PCI_PFAB_BAR0                                                (0x00000204)
#define PCI_PFAB_BAR0_UPPER                                          (0x00000208)
#define PCI_PFAB_IO                                                  (0x0000020c)
#define PCI_PFAB_IO_UPPER                                            (0x00000210)
#define PCI_PFAB_MEM32                                               (0x00000214)
#define PCI_PFAB_MEM32_REMAP                                         (0x00000218)
#define PCI_PFAB_MEM32_MASK                                          (0x0000021c)
#define PCI_PFAB_PFM3                                                (0x00000220)
#define PCI_PFAB_PFM3_REMAP_UPPER                                    (0x00000224)
#define PCI_PFAB_PFM3_REMAP_LOWER                                    (0x00000228)
#define PCI_PFAB_PFM3_MASK                                           (0x0000022c)
#define PCI_PFAB_PFM4                                                (0x00000230)
#define PCI_PFAB_PFM4_REMAP_UPPER                                    (0x00000234)
#define PCI_PFAB_PFM4_REMAP_LOWER                                    (0x00000238)
#define PCI_PFAB_PFM4_MASK                                           (0x0000023c)
#define PCI_PFAB_SYNC_BAR                                            (0x00000240)
#define PCI_PFAB_SYNC_BAR_UPPER                                      (0x00000244)
#define PCI_EROM_MAP                                                 (0x000002fc)

#define MAX_PCI_LUTS												 32
#define MAX_PCI_LUT_UPPERS											 32

#define PCI_P2O_FAB_BAR2_LUTX(x)                                     (0x00000500 + (x)*8)
#define PCI_P2O_FAB_BAR2_LUT_UPPERX(x)                               (0x00000504 + (x)*8)

#define PCI_P2O_FAB_BAR3_LUTX(x)                                     (0x00000600 + (x)*8)
#define PCI_P2O_FAB_BAR3_LUT_UPPERX(x)                               (0x00000604 + (x)*8)

/* ************************************************ */
/* PCI : Register Bit Masks and Reset Values    */
/*           definitions for every register         */
/* ************************************************ */

/* PCI_PE_ID : Reset Values */
#define PCI_VID_TUNDRA                                               (0x10e3)
#define PCI_DID_TSI108                                               (0x0108)
#define PCI_DID_TSI108A                                              (0xA108)
// note TSI109 has same device ID as TSI108A
#define PCI_DID_TSI109                                               (0xA108)

/* PCI_PE_ID : Register Bits Masks Definitions */
#define PCI_PE_ID_VID                                                (0x0000ffff)
#define PCI_PE_ID_DID                                                (0xffff0000)

/* PCI_PE_CSR : Register Bits Masks Definitions */
#define PCI_PE_CSR_IOS                                               (0x00000001)
#define PCI_PE_CSR_MS                                                (0x00000002)
#define PCI_PE_CSR_BM                                                (0x00000004)
#define PCI_PE_CSR_SC                                                (0x00000008)
#define PCI_PE_CSR_MWI_EN                                            (0x00000010)
#define PCI_PE_CSR_VGAPS                                             (0x00000020)
#define PCI_PE_CSR_PERESP                                            (0x00000040)
#define PCI_PE_CSR_WAIT                                              (0x00000080)
#define PCI_PE_CSR_SERR_EN                                           (0x00000100)
#define PCI_PE_CSR_MFBBC                                             (0x00000200)
#define PCI_PE_CSR_INT_DIS                                           (0x00000400)
#define PCI_PE_CSR_INT_STAT                                          (0x00080000)
#define PCI_PE_CSR_CAP_L                                             (0x00100000)
#define PCI_PE_CSR_DEV66                                             (0x00200000)
#define PCI_PE_CSR_TFBBC                                             (0x00800000)
#define PCI_PE_CSR_MDP_D                                             (0x01000000)
#define PCI_PE_CSR_DEVSEL                                            (0x06000000)
#define PCI_PE_CSR_S_TA                                              (0x08000000)
#define PCI_PE_CSR_R_TA                                              (0x10000000)
#define PCI_PE_CSR_R_MA                                              (0x20000000)
#define PCI_PE_CSR_S_SERR                                            (0x40000000)
#define PCI_PE_CSR_D_PE                                              (0x80000000)
#define PCI_PE_CSR_RESERVED                                          (0x0047f800)

/* PCI_PE_CLASS : Register Bits Masks Definitions */
#define PCI_PE_CLASS_RID                                             (0x000000ff)
#define PCI_PE_CLASS_PROG                                            (0x0000ff00)
#define PCI_PE_CLASS_SUB                                             (0x00ff0000)
#define PCI_PE_CLASS_BASE                                            (0xff000000)
#define PCI_PE_CLASS_RESERVED                                        (0x00000000)

/* PCI_PE_MISC0 : Register Bits Masks Definitions */
#define PCI_PE_MISC0_CLINE                                           (0x000000ff)
#define PCI_PE_MISC0_LTIMER                                          (0x0000ff00)
#define PCI_PE_MISC0_LAYOUT                                          (0x007f0000)
#define PCI_PE_MISC0_MFUNCT                                          (0x00800000)
#define PCI_PE_MISC0_CCODE                                           (0x0f000000)
#define PCI_PE_MISC0_SBIST                                           (0x40000000)
#define PCI_PE_MISC0_BISTC                                           (0x80000000)
#define PCI_PE_MISC0_RESERVED                                        (0x30000000)

/* PCI_P2O_BAR0 : Register Bits Masks Definitions */
#define PCI_P2O_BAR0_IO_MODE                                         (0x00000001)
#define PCI_P2O_BAR0_TYPE                                            (0x00000006)
#define PCI_P2O_BAR0_PRFTCH                                          (0x00000008)
#define PCI_P2O_BAR0_BA                                              (0xffff0000)
#define PCI_P2O_BAR0_RESERVED                                        (0x0000fff0)

/* PCI_P2O_BAR0_UPPER : Register Bits Masks Definitions */
#define PCI_P2O_BAR0_UPPER_BA                                        (0xffffffff)

/* PCI_P2O_BAR2 : Register Bits Masks Definitions */
#define PCI_P2O_BAR2_IO_MODE                                         (0x00000001)
#define PCI_P2O_BAR2_TYPE                                            (0x00000006)
#define PCI_P2O_BAR2_PRFTCH                                          (0x00000008)
#define PCI_P2O_BAR2_BA                                              (0xffff8000)
#define PCI_P2O_BAR2_RESERVED                                        (0x00007ff0)

/* PCI_P2O_BAR2_UPPER : Register Bits Masks Definitions */
#define PCI_P2O_BAR2_UPPER_BA                                        (0xffffffff)

/* PCI_P2O_BAR3 : Register Bits Masks Definitions */
#define PCI_P2O_BAR3_IO_MODE                                         (0x00000001)
#define PCI_P2O_BAR3_TYPE                                            (0x00000006)
#define PCI_P2O_BAR3_PRFTCH                                          (0x00000008)
#define PCI_P2O_BAR3_BA                                              (0xffff8000)
#define PCI_P2O_BAR3_RESERVED                                        (0x00007ff0)

/* PCI_P2O_BAR3_UPPER : Register Bits Masks Definitions */
#define PCI_P2O_BAR3_UPPER_BA                                        (0xffffffff)

/* PCI_PE_SID : Register Bits Masks Definitions */
#define PCI_PE_SID_SVID                                              (0x0000ffff)
#define PCI_PE_SID_SID                                               (0xffff0000)

/* PCI_PE_ROM : Register Bits Masks Definitions */
#define PCI_PE_ROM_EN                                                (0x00000001)
#define PCI_PE_ROM_BA                                                (0xfe000000)
#define PCI_PE_ROM_RESERVED                                          (0x01fffffe)

/* PCI_PE_CAP : Register Bits Masks Definitions */
#define PCI_PE_CAP_CAP_PTR                                           (0x000000ff)
#define PCI_PE_CAP_RESERVED                                          (0xffffff00)

/* PCI_PE_MISC2 : Register Bits Masks Definitions */
#define PCI_PE_MISC2_INT_LINE                                        (0x000000ff)
#define PCI_PE_MISC2_INT_PIN                                         (0x0000ff00)
#define PCI_PE_MISC2_S_PERESP                                        (0x00010000)
#define PCI_PE_MISC2_SERR_FOR                                        (0x00020000)
#define PCI_PE_MISC2_ISA_EN                                          (0x00040000)
#define PCI_PE_MISC2_VGA_EN                                          (0x00080000)
#define PCI_PE_MISC2_MA_ERR                                          (0x00200000)
#define PCI_PE_MISC2_S_RESET                                         (0x00400000)
#define PCI_PE_MISC2_S_FPEP_EN                                       (0x00800000)
#define PCI_PE_MISC2_DISCARD1                                        (0x01000000)
#define PCI_PE_MISC2_DISCARD2                                        (0x02000000)
#define PCI_PE_MISC2_DISCARD_STAT                                    (0x04000000)
#define PCI_PE_MISC2_DISCARD_SERR                                    (0x08000000)

/* PCI_MISC_CSR : Register Bits Masks Definitions */
#define PCI_MISC_CSR_BAR0_EN                                         (0x00000002)
#define PCI_MISC_CSR_EN_1K                                           (0x00000004)
#define PCI_MISC_CSR_PRIMARY                                         (0x00000020)
#define PCI_MISC_CSR_SOFT_RESET                                      (0x00000040)
#define PCI_MISC_CSR_LOCKOUT                                         (0x00000080)
#define PCI_MISC_CSR_D64                                             (0x00000100)
#define PCI_MISC_CSR_CTL_RSC                                         (0x00000200)
#define PCI_MISC_CSR_M66EN                                           (0x00000400)
#define PCI_MISC_CSR_VPD_EN                                          (0x00008000)
#define PCI_MISC_CSR_TUNDRA_VER_ID                                   (0x00ff0000)
#define PCI_MISC_CSR_TUNDRA_DEV_ID                                   (0xff000000)
#define PCI_MISC_CSR_RWMASK                                          (0x000080c6)
#define PCI_MISC_CSR_RESERVED                                        (0x00007819)

/* PCI_SERR_DIS : Register Bits Masks Definitions */
#define PCI_SERR_DIS_PW_RETRY                                        (0x00000004)
#define PCI_SERR_DIS_PW_TA                                           (0x00000008)
#define PCI_SERR_DIS_PW_MA                                           (0x00000010)
#define PCI_SERR_DIS_DW_ND                                           (0x00000020)
#define PCI_SERR_DIS_DR_ND                                           (0x00000040)
#define PCI_SERR_DIS_RESERVED                                        (0xffffff83)

/* PCI_SERR_STAT : Register Bits Masks Definitions */
#define PCI_SERR_STAT_APE                                            (0x00000001)
#define PCI_SERR_STAT_PW_DPE                                         (0x00000002)
#define PCI_SERR_STAT_PW_RETRY                                       (0x00000004)
#define PCI_SERR_STAT_PW_TA                                          (0x00000008)
#define PCI_SERR_STAT_PW_MA                                          (0x00000010)
#define PCI_SERR_STAT_DW_ND                                          (0x00000020)
#define PCI_SERR_STAT_DR_ND                                          (0x00000040)
#define PCI_SERR_STAT_D_TOUT                                         (0x00000080)
#define PCI_SERR_STAT_RESERVED                                       (0xffffff00)

/* PCI_P2O_PAGE_SIZES : Register Bits Masks Definitions */
#define PCI_P2O_PAGE_SIZES_BAR3_EN                                   (0x00000001)
#define PCI_P2O_PAGE_SIZES_BAR3_NOTRAN                               (0x00000004)
#define PCI_P2O_PAGE_SIZES_BAR3_SIZE                                 (0x000000f8)
#define PCI_P2O_PAGE_SIZES_BAR2_EN                                   (0x00000100)
#define PCI_P2O_PAGE_SIZES_BAR2_NOTRAN                               (0x00000400)
#define PCI_P2O_PAGE_SIZES_BAR2_SIZE                                 (0x0000f800)
#define PCI_P2O_PAGE_SIZES_RESERVED                                  (0xffff0202)

/* PCI_P_VPD_CSR : Register Bits Masks Definitions */
#define PCI_P_VPD_CSR_VPD_OFFSET                                     (0x00fffff0)
#define PCI_P_VPD_CSR_VPD_PORT_NUM                                   (0xe0000000)
#define PCI_P_VPD_CSR_RWMASK                                         (0xe0fffff0)
#define PCI_P_VPD_CSR_RESERVED                                       (0x1f00000f)


/* PCI_P_SLOT_ID : Register Bits Masks Definitions */
#define PCI_P_SLOT_ID_CAP_ID                                         (0x000000ff)
#define PCI_P_SLOT_ID_NXT_PTR                                        (0x0000ff00)
#define PCI_P_SLOT_ID_EXP_SLOT                                       (0x001f0000)
#define PCI_P_SLOT_ID_FIC                                            (0x00200000)
#define PCI_P_SLOT_ID_CHASSIS                                        (0xff000000)
#define PCI_P_SLOT_ID_RESERVED                                       (0x00c00000)

/* PCI_P_PMC : Register Bits Masks Definitions */
#define PCI_P_PMC_CAP_ID                                             (0x000000ff)
#define PCI_P_PMC_NXT_PTR                                            (0x0000ff00)
#define PCI_P_PMC_PM_VER                                             (0x00070000)
#define PCI_P_PMC_PME_CK                                             (0x00080000)
#define PCI_P_PMC_DSI                                                (0x00200000)
#define PCI_P_PMC_D1_SP                                              (0x02000000)
#define PCI_P_PMC_D2_SP                                              (0x04000000)
#define PCI_P_PMC_PME_SUP                                            (0xf8000000)
#define PCI_P_PMC_RESERVED                                           (0x01d00000)

/* PCI_P_PMCS : Register Bits Masks Definitions */
#define PCI_P_PMCS_PWR_ST                                            (0x00000003)
#define PCI_P_PMCS_PME_EN                                            (0x00000100)
#define PCI_P_PMCS_PME_ST                                            (0x00008000)
#define PCI_P_PMCS_B2_B3                                             (0x00400000)
#define PCI_P_PMCS_BPCC_EN                                           (0x00800000)
#define PCI_P_PMCS_RESERVED                                          (0xff3f7efc)

/* PCI_P_HS_CSR : Register Bits Masks Definitions */
#define PCI_P_HS_CSR_CAP_ID                                          (0x000000ff)
#define PCI_P_HS_CSR_NXT_PTR                                         (0x0000ff00)
#define PCI_P_HS_CSR_EIM                                             (0x00020000)
#define PCI_P_HS_CSR_LOO                                             (0x00080000)
#define PCI_P_HS_CSR_EXT                                             (0x00400000)
#define PCI_P_HS_CSR_INS                                             (0x00800000)
#define PCI_P_HS_CSR_RESERVED                                        (0xff350000)

/* PCI_P_VPDC : Register Bits Masks Definitions */
#define PCI_P_VPDC_CAP_ID                                            (0x000000ff)
#define PCI_P_VPDC_NXT_PTR                                           (0x0000ff00)
#define PCI_P_VPDC_VPDA                                              (0x00ff0000)
#define PCI_P_VPDC_F                                                 (0x80000000)
#define PCI_P_VPDC_RESERVED                                          (0x7f000000)

/* PCI_P_VPDD : Register Bits Masks Definitions */
#define PCI_P_VPDD_VPD_DATA                                          (0xffffffff)

/* PCI_P_MSIC : Register Bits Masks Definitions */
#define PCI_P_MSIC_CAP_ID                                            (0x000000ff)
#define PCI_P_MSIC_NXT_PTR                                           (0x0000ff00)
#define PCI_P_MSIC_MSI_EN                                            (0x00010000)
#define PCI_P_MSIC_MM_CAP                                            (0x000e0000)
#define PCI_P_MSIC_MM_EN                                             (0x00700000)
#define PCI_P_MSIC_CAP64                                             (0x00800000)
#define PCI_P_MSIC_RESERVED                                          (0xff000000)

/* PCI_P_MSIA : Register Bits Masks Definitions */
#define PCI_P_MSIA_MSI_ADDR                                          (0xfffffffc)
#define PCI_P_MSIA_RESERVED                                          (0x00000003)

/* PCI_P_MSIA_UPPER : Register Bits Masks Definitions */
#define PCI_P_MSIA_UPPER_MSI_ADDR                                    (0xffffffff)

/* PCI_P_MSID : Register Bits Masks Definitions */
#define PCI_P_MSID_MSI_DATA                                          (0x0000ffff)
#define PCI_P_MSID_RESERVED                                          (0xffff0000)

/* PCI_PE_PCIX_C : Register Bits Masks Definitions */
#define PCI_PE_PCIX_C_CAP_ID                                         (0x000000ff)
#define PCI_PE_PCIX_C_NXT_PTR                                        (0x0000ff00)
#define PCI_PE_PCIX_C_P_DPERR                                        (0x00010000)
#define PCI_PE_PCIX_C_RO_EN                                          (0x00020000)
#define PCI_PE_PCIX_C_MAX_BC                                         (0x000c0000)
#define PCI_PE_PCIX_C_MAX_SPLIT                                      (0x00700000)
#define PCI_PE_PCIX_C_RESERVED                                       (0xff800000)

/* PCI_PE_PCI/X_S : Register Bits Masks Definitions */
#define PCI_PE_PCIX_S_FUNC_NUM                                      (0x00000007)
#define PCI_PE_PCIX_S_DEV_NUM                                       (0x000000f8)
#define PCI_PE_PCIX_S_BUS_NUM                                       (0x0000ff00)
#define PCI_PE_PCIX_S_P_D64                                         (0x00010000)
#define PCI_PE_PCIX_S_P_133CAP                                      (0x00020000)
#define PCI_PE_PCIX_S_P_SCD                                         (0x00040000)
#define PCI_PE_PCIX_S_P_USC                                         (0x00080000)
#define PCI_PE_PCIX_S_P_COMP                                        (0x00100000)
#define PCI_PE_PCIX_S_P_MAX_RD                                      (0x00600000)
#define PCI_PE_PCIX_S_P_MAX_SPLIT                                   (0x03800000)
#define PCI_PE_PCIX_S_P_MAX_CUM                                     (0x1c000000)
#define PCI_PE_PCIX_S_P_RSCE                                        (0x20000000)
#define PCI_PE_PCIX_S_RESERVED                                      (0xc0000000)

/* PCI_ARB_CTRL : Register Bits Masks Definitions */
#define PCI_ARB_CTRL_BM_PARK                                         (0x00000007)
#define PCI_ARB_CTRL_PARK                                            (0x00000008)
#define PCI_ARB_CTRL_TO_CNT                                          (0x000000c0)
#define PCI_ARB_CTRL_MY_PRI                                          (0x00000100)
#define PCI_ARB_CTRL_M1_PRI                                          (0x00000200)
#define PCI_ARB_CTRL_M2_PRI                                          (0x00000400)
#define PCI_ARB_CTRL_M3_PRI                                          (0x00000800)
#define PCI_ARB_CTRL_M4_PRI                                          (0x00001000)
#define PCI_ARB_CTRL_M5_PRI                                          (0x00002000)
#define PCI_ARB_CTRL_M6_PRI                                          (0x00004000)
#define PCI_ARB_CTRL_M7_PRI                                          (0x00008000)
#define PCI_ARB_CTRL_RESERVED                                        (0xffff0030)

/* PCI_IRP_CFG_CTL : Register Bits Masks Definitions */
#define PCI_IRP_CFG_CTL_INTA_DIR                                     (0x00000001)
#define PCI_IRP_CFG_CTL_INTB_DIR                                     (0x00000002)
#define PCI_IRP_CFG_CTL_INTC_DIR                                     (0x00000004)
#define PCI_IRP_CFG_CTL_INTD_DIR                                     (0x00000008)
#define PCI_IRP_CFG_CTL_LOC_INT_DEST                                 (0x00000030)
#define PCI_IRP_CFG_CTL_INTA_TYPE                                    (0x00000300)
#define PCI_IRP_CFG_CTL_INTB_TYPE                                    (0x00000c00)
#define PCI_IRP_CFG_CTL_INTC_TYPE                                    (0x00003000)
#define PCI_IRP_CFG_CTL_INTD_TYPE                                    (0x0000c000)
#define PCI_IRP_CFG_CTL_RESERVED                                     (0xffff00c0)

/* PCI_IRP_STAT : Register Bits Masks Definitions */
#define PCI_IRP_STAT_SPR_TMO                                         (0x00010000)
#define PCI_IRP_STAT_FAB                                             (0x00020000)
#define PCI_IRP_STAT_HS_CSR                                          (0x00100000)
#define PCI_IRP_STAT_P_INT                                           (0x00400000)
#define PCI_IRP_STAT_P_CSR                                           (0x00800000)
#define PCI_IRP_STAT_APE                                             (0x01000000)
#define PCI_IRP_STAT_PW_DPE                                          (0x02000000)
#define PCI_IRP_STAT_PW_RETRY                                        (0x04000000)
#define PCI_IRP_STAT_PW_TA                                           (0x08000000)
#define PCI_IRP_STAT_PW_MA                                           (0x10000000)
#define PCI_IRP_STAT_DW_ND                                           (0x20000000)
#define PCI_IRP_STAT_DR_ND                                           (0x40000000)
#define PCI_IRP_STAT_RESERVED                                        (0x802cffff)

/* PCI_IRP_ENABLE : Register Bits Masks Definitions */
#define PCI_IRP_ENABLE_SPR_TMO                                       (0x00010000)
#define PCI_IRP_ENABLE_FAB                                           (0x00020000)
#define PCI_IRP_ENABLE_HS_CSR                                        (0x00100000)
#define PCI_IRP_ENABLE_P_INT                                         (0x00400000)
#define PCI_IRP_ENABLE_P_CSR                                         (0x00800000)
#define PCI_IRP_ENABLE_APE                                           (0x01000000)
#define PCI_IRP_ENABLE_PW_DPE                                        (0x02000000)
#define PCI_IRP_ENABLE_PW_RETRY                                      (0x04000000)
#define PCI_IRP_ENABLE_PW_TA                                         (0x08000000)
#define PCI_IRP_ENABLE_PW_MA                                         (0x10000000)
#define PCI_IRP_ENABLE_DW_ND                                         (0x20000000)
#define PCI_IRP_ENABLE_DR_ND                                         (0x40000000)
#define PCI_IRP_ENABLE_RESERVED                                      (0x802cffff)

/* PCI_IRP_INTAD : Register Bits Masks Definitions */
#define PCI_IRP_INTAD_INTA                                           (0x00000001)
#define PCI_IRP_INTAD_INTB                                           (0x00000002)
#define PCI_IRP_INTAD_INTC                                           (0x00000004)
#define PCI_IRP_INTAD_INTD                                           (0x00000008)
#define PCI_IRP_INTAD_PME                                            (0x00000010)
#define PCI_IRP_INTAD_INTA_EN                                        (0x00010000)
#define PCI_IRP_INTAD_INTB_EN                                        (0x00020000)
#define PCI_IRP_INTAD_INTC_EN                                        (0x00040000)
#define PCI_IRP_INTAD_INTD_EN                                        (0x00080000)
#define PCI_IRP_INTAD_RESERVED                                       (0xfff0ffe0)

/* PCI_P_VID_OVERRIDE : Register Bits Masks Definitions */
#define PCI_P_VID_OVERRIDE_VID                                       (0x0000ffff)
#define PCI_P_VID_OVERRIDE_DID                                       (0xffff0000)

/* PCI_P_CLASS_OVERRIDE : Register Bits Masks Definitions */
#define PCI_P_CLASS_OVERRIDE_RID                                     (0x000000ff)
#define PCI_P_CLASS_OVERRIDE_PROG                                    (0x0000ff00)
#define PCI_P_CLASS_OVERRIDE_SUB                                     (0x00ff0000)
#define PCI_P_CLASS_OVERRIDE_BASE                                    (0xff000000)

/* PCI_PE_SID_OVERRIDE : Register Bits Masks Definitions */
#define PCI_PE_SID_OVERRIDE_SVID                                     (0x0000ffff)
#define PCI_PE_SID_OVERRIDE_SID                                      (0xffff0000)

/* PCI_P_SLOT_ID_OVERRIDE : Register Bits Masks Definitions */
#define PCI_P_SLOT_ID_OVERRIDE_EXP_SLOT                              (0x001f0000)
#define PCI_P_SLOT_ID_OVERRIDE_FIC                                   (0x00200000)
#define PCI_P_SLOT_ID_OVERRIDE_CHASSIS                               (0xff000000)
#define PCI_P_SLOT_ID_OVERRIDE_RESERVED                              (0x00c0ffff)

/* PCI_PFAB_CSR : Register Bits Masks Definitions */
#define PCI_PFAB_CSR_BSWAP                                           (0x00000001)
#define PCI_PFAB_CSR_WSWAP                                           (0x00000002)
#define PCI_PFAB_CSR_CFG_BSWAP                                       (0x00000004)
#define PCI_PFAB_CSR_TIME_EN0                                        (0x00000008)
#define PCI_PFAB_CSR_BAR4_EN                                         (0x00000010)
#define PCI_PFAB_CSR_BAR4_SIZE                                       (0x00000020)
#define PCI_PFAB_CSR_BAR4_30                                         (0x00000040)
#define PCI_PFAB_CSR_BAR4_31                                         (0x00000080)
#define PCI_PFAB_CSR_SW_RST                                          (0x00000100)
#define PCI_PFAB_CSR_COMP_BAR_MODE                                   (0x00000200)
#define PCI_PFAB_CSR_OCN_RLX_ORDER                                   (0x00000400)
#define PCI_PFAB_CSR_TIME_EN1                                        (0x00000800)
#define PCI_PFAB_CSR_BAR3_EN                                         (0x00001000)
#define PCI_PFAB_CSR_BAR3_SIZE                                       (0x00002000)
#define PCI_PFAB_CSR_BAR3_30                                         (0x00004000)
#define PCI_PFAB_CSR_BAR3_31                                         (0x00008000)
#define PCI_PFAB_CSR_INT_ENABLE_MASK                                 (0x00ff0000)
#define PCI_PFAB_CSR_INVLD_RESP                                      (0x01000000)
#define PCI_PFAB_CSR_RESP_TIMOUT                                     (0x04000000)
#define PCI_PFAB_CSR_TEA                                             (0x10000000)
#define PCI_PFAB_CSR_BAD_P2O_PKT                                     (0x20000000)
#define PCI_PFAB_CSR_SYNC_OVRN                                       (0x40000000)
#define PCI_PFAB_CSR_O2P_BAR_RESP                                    (0x80000000)
#define PCI_PFAB_CSR_RESERVED                                        (0x0a000000)

/* PCI_PFAB_BAR0 : Register Bits Masks Definitions */
#define PCI_PFAB_BAR0_BAR0_EN                                        (0x00000001)
#define PCI_PFAB_BAR0_PFAB_BAR0                                      (0xff000000)
#define PCI_PFAB_BAR0_RESERVED                                       (0x00fffffe)

/* PCI_PFAB_BAR0_UPPER : Register Bits Masks Definitions */
#define PCI_PFAB_BAR0_UPPER_PFAB_BAR0                                (0xffffffff)

/* PCI_PFAB_IO : Register Bits Masks Definitions */
#define PCI_PFAB_IO_EN                                               (0x00000001)
#define PCI_PFAB_IO_BAR                                              (0xffff0000)
#define PCI_PFAB_IO_RESERVED                                         (0x0000fffe)

/* PCI_PFAB_IO_UPPER : Register Bits Masks Definitions */
#define PCI_PFAB_IO_UPPER_BAR                                        (0xffffffff)

/* PCI_PFAB_MEM32 : Register Bits Masks Definitions */
#define PCI_PFAB_MEM32_EN                                            (0x00010000)
#define PCI_PFAB_MEM32_SIZE                                          (0x00020000)
#define PCI_PFAB_MEM32_BA                                            (0xe0000000)
#define PCI_PFAB_MEM32_RESERVED                                      (0x1ffcffff)

/* PCI_PFAB_MEM32_REMAP : Register Bits Masks Definitions */
#define PCI_PFAB_MEM32_REMAP_Remap                                   (0xe0000000)
#define PCI_PFAB_MEM32_REMAP_RWMASK                                  (0xe0000000)
#define PCI_PFAB_MEM32_REMAP_RESERVED                                (0x1fffffff)

/* PCI_PFAB_MEM32_MASK : Register Bits Masks Definitions */
#define PCI_PFAB_MEM32_MASK_Mask                                     (0xe0000000)
#define PCI_PFAB_MEM32_MASK_RWMASK                                   (0xe0000000)
#define PCI_PFAB_MEM32_MASK_RESERVED                                 (0x1fffffff)

/* PCI_PFAB_PFMX : Register Bits Masks Definitions */
#define PCI_PFAB_PFMX_BA_47_32                                       (0x0000ffff)
#define PCI_PFAB_PFMX_EN                                             (0x00010000)
#define PCI_PFAB_PFMX_SIZE                                           (0x00020000)
#define PCI_PFAB_PFMX_BA_59_48                                       (0x3ffc0000)
#define PCI_PFAB_PFMX_BA_31_30                                       (0xc0000000)

/* PCI_PFAB_PFMX_REMAP_UPPER : Register Bits Masks Definitions */
#define PCI_PFAB_PFMX_REMAP_UPPER_Remap                              (0xfffff000)
#define PCI_PFAB_PFMX_REMAP_UPPER_RESERVED                           (0x00000fff)

/* PCI_PFAB_PFMX_REMAP_LOWER : Register Bits Masks Definitions */
#define PCI_PFAB_PFMX_REMAP_LOWER_Remap                              (0xffffffff)

/* PCI_PFAB_PFMX_MASK : Register Bits Masks Definitions */
#define PCI_PFAB_PFMX_MASK_Mask                                      (0xffffffff)

/* PCI_PFAB_SYNC_BAR : Register Bits Masks Definitions */
#define PCI_PFAB_SYNC_BAR_EN                                         (0x00000001)
#define PCI_PFAB_SYNC_BAR_SYNC_BAR                                   (0xffffff00)
#define PCI_PFAB_SYNC_BAR_RESERVED                                   (0x000000fe)

/* PCI_PFAB_SYNC_BAR_UPPER : Register Bits Masks Definitions */
#define PCI_PFAB_SYNC_BAR_UPPER_SYNC_BAR                             (0xffffffff)

/* PCI_EROM_MAP : Register Bits Masks Definitions */
#define PCI_EROM_MAP_DST                                             (0x0000000f)
#define PCI_EROM_MAP_MAP                                             (0xfe000000)
#define PCI_EROM_MAP_RESERVED                                        (0x01fffff0)

/* PCI_P2O_FAB_BAR_LUTX : Register Bits Masks Definitions */
#define PCI_P2O_FAB_BAR_LUTX_FAB_BAR_DESTID                          (0x0000000f)
#define PCI_P2O_FAB_BAR_LUTX_FAB_BAR_PAGE_ADDR                       (0xffffffe0)
#define PCI_P2O_FAB_BAR_LUTX_RESERVED                                (0x00000010)

/* PCI_P2O_FAB_BAR_LUT_UPPERX : Register Bits Masks Definitions */
#define PCI_P2O_FAB_BAR_LUT_UPPERX_FAB_BAR_PAGE_ADDR                 (0xffffffff)

/* PCI_P2O_BAR2_LUTX : Register Bits Masks Definitions */
#define PCI_P2O_BAR2_LUTX_BAR2_DESTID                                (0x0000000f)
#define PCI_P2O_BAR2_LUTX_BAR2_PAGE_ADDR                             (0xfffffc00)
#define PCI_P2O_BAR2_LUTX_RESERVED                                   (0x000003f0)

/* PCI_P2O_BAR2_LUT_UPPERX : Register Bits Masks Definitions */
#define PCI_P2O_BAR2_LUT_UPPERX_BAR2_PAGE_ADDR                       (0xffffffff)

/* PCI_P2O_BAR3_LUTX : Register Bits Masks Definitions */
#define PCI_P2O_BAR3_LUTX_BAR3_DESTID                                (0x0000000f)
#define PCI_P2O_BAR3_LUTX_BAR3_PAGE_ADDR                             (0xfffffc00)
#define PCI_P2O_BAR3_LUTX_RESERVED                                   (0x000003f0)

/* PCI_P2O_BAR3_LUT_UPPERX : Register Bits Masks Definitions */
#define PCI_P2O_BAR3_LUT_UPPERX_BAR3_PAGE_ADDR                       (0xffffffff)

#endif /* _TS_PCI_H_  */
